==> qore-0.8.12.2.tar.bz2: qore-0.8.12.2/docs/lang/html/group__system__and__build__constants.js <==
var group__system__and__build__constants =
[
    [ "Build", "group__system__and__build__constants.html#gaf309af16653ccf009d207a851a3bc40f", null ],
    [ "BuildHost", "group__system__and__build__constants.html#ga02838c0996b5ddca780babc786eeb0d8", null ],
    [ "CFLAGS", "group__system__and__build__constants.html#ga4706dc06313216a4c4252d7024809487", null ],
    [ "Compiler", "group__system__and__build__constants.html#gab870ef28f525648a43a31c859a2a6d06", null ],
    [ "DirSep", "group__system__and__build__constants.html#ga6cebae5097d4414ca8c6da4be8cf9922", null ],
    [ "LDFLAGS", "group__system__and__build__constants.html#ga8130bc03e3d8254eaf0d91ef4dbce1cf", null ],
    [ "MACHINE_MSB", "group__system__and__build__constants.html#gace8e995e657fc1299783e55b90eda812", null ],
    [ "Platform", "group__system__and__build__constants.html#ga003f84c29bc6d145ea7ab890cadc5b41", null ],
    [ "PlatformCPU", "group__system__and__build__constants.html#gac7364290dc6b93298baabb32da286c5b", null ],
    [ "PlatformOS", "group__system__and__build__constants.html#ga0df3f3321bde2c7e8c25cab85a94c0a5", null ],
    [ "VersionMajor", "group__system__and__build__constants.html#ga981ec5d46693e04ec68a953c96950b97", null ],
    [ "VersionMinor", "group__system__and__build__constants.html#ga2951ba69a965973d76898d671270fd9e", null ],
    [ "VersionString", "group__system__and__build__constants.html#gadc4aece84a7f703cb7f2da77f18980b8", null ],
    [ "VersionSub", "group__system__and__build__constants.html#ga92cc5129c80534fbc9c887321a582264", null ]
];

==> qore-0.9.10.tar.bz2: qore-0.9.10/docs/lang/html/group__system__and__build__constants.js <==
var group__system__and__build__constants =
[
    [ "Build", "group__system__and__build__constants.html#gaf309af16653ccf009d207a851a3bc40f", null ],
    [ "BuildHost", "group__system__and__build__constants.html#ga02838c0996b5ddca780babc786eeb0d8", null ],
    [ "CFLAGS", "group__system__and__build__constants.html#ga4706dc06313216a4c4252d7024809487", null ],
    [ "Compiler", "group__system__and__build__constants.html#gab870ef28f525648a43a31c859a2a6d06", null ],
    [ "DirSep", "group__system__and__build__constants.html#ga6cebae5097d4414ca8c6da4be8cf9922", null ],
    [ "LDFLAGS", "group__system__and__build__constants.html#ga8130bc03e3d8254eaf0d91ef4dbce1cf", null ],
    [ "MACHINE_MSB", "group__system__and__build__constants.html#gace8e995e657fc1299783e55b90eda812", null ],
    [ "PathSep", "group__system__and__build__constants.html#ga92a67b51fbd91b3f09ccb8fd84fd8975", null ],
    [ "Platform", "group__system__and__build__constants.html#ga003f84c29bc6d145ea7ab890cadc5b41", null ],
    [ "PlatformCPU", "group__system__and__build__constants.html#gac7364290dc6b93298baabb32da286c5b", null ],
    [ "PlatformOS", "group__system__and__build__constants.html#ga0df3f3321bde2c7e8c25cab85a94c0a5", null ],
    [ "VersionMajor", "group__system__and__build__constants.html#ga981ec5d46693e04ec68a953c96950b97", null ],
    [ "VersionMinor", "group__system__and__build__constants.html#ga2951ba69a965973d76898d671270fd9e", null ],
    [ "VersionString", "group__system__and__build__constants.html#gadc4aece84a7f703cb7f2da77f18980b8", null ],
    [ "VersionSub", "group__system__and__build__constants.html#ga92cc5129c80534fbc9c887321a582264", null ]
];
